@@ -4,9 +4,9 @@
  *
  *  $RCSfile: ADatabaseMetaData.cxx,v $
  *
- *  $Revision: 1.19 $
+ *  $Revision: 1.20 $
  *
- *  last change: $Author: obo $ $Date: 2005/12/21 13:14:47 $
+ *  last change: $Author: hr $ $Date: 2006/06/20 01:12:47 $
  *
  *  The Contents of this file are made available subject to
  *  the terms of GNU Lesser General Public License Version 2.1.
@@ -62,6 +62,9 @@
 #ifndef _COMPHELPER_TYPES_HXX_
 #include <comphelper/types.hxx>
 #endif
+#ifndef _DBHELPER_DBEXCEPTION_HXX_
+#include <connectivity/dbexception.hxx>
+#endif
 
 using namespace ::comphelper;
 
@@ -139,11 +142,11 @@ Reference< XResultSet > SAL_CALL ODatabaseMetaData::getCatalogs(  ) throw(SQLExc
 	ADOS::ThrowException(*m_pADOConnection,*this);
 
 	Reference< XResultSet > xRef;
-	
+
 	ODatabaseMetaDataResultSet* pResult = new ODatabaseMetaDataResultSet(pRecordset);
 	pResult->setCatalogsMap();
 	xRef = pResult;
-	
+
 	return xRef;
 }
 // -------------------------------------------------------------------------
@@ -162,37 +165,37 @@ Reference< XResultSet > SAL_CALL ODatabaseMetaData::getSchemas(  ) throw(SQLExce
 	ADOS::ThrowException(*m_pADOConnection,*this);
 
 	Reference< XResultSet > xRef;
-	
+
 	ODatabaseMetaDataResultSet* pResult = new ODatabaseMetaDataResultSet(pRecordset);
 	pResult->setSchemasMap();
 	xRef = pResult;
 	return xRef;
 }
 // -------------------------------------------------------------------------
-Reference< XResultSet > SAL_CALL ODatabaseMetaData::getColumnPrivileges( 
-	const Any& catalog, const ::rtl::OUString& schema, const ::rtl::OUString& table, 
+Reference< XResultSet > SAL_CALL ODatabaseMetaData::getColumnPrivileges(
+	const Any& catalog, const ::rtl::OUString& schema, const ::rtl::OUString& table,
 	const ::rtl::OUString& columnNamePattern ) throw(SQLException, RuntimeException)
 {
 	ADORecordset *pRecordset = m_pADOConnection->getColumnPrivileges(catalog,schema,table,columnNamePattern);
 	ADOS::ThrowException(*m_pADOConnection,*this);
 
 	Reference< XResultSet > xRef;
-	
+
 	ODatabaseMetaDataResultSet* pResult = new ODatabaseMetaDataResultSet(pRecordset);
 	pResult->setColumnPrivilegesMap();
 	xRef = pResult;
 	return xRef;
 }
 // -------------------------------------------------------------------------
-Reference< XResultSet > SAL_CALL ODatabaseMetaData::getColumns( 
-	const Any& catalog, const ::rtl::OUString& schemaPattern, const ::rtl::OUString& tableNamePattern, 
+Reference< XResultSet > SAL_CALL ODatabaseMetaData::getColumns(
+	const Any& catalog, const ::rtl::OUString& schemaPattern, const ::rtl::OUString& tableNamePattern,
 	const ::rtl::OUString& columnNamePattern ) throw(SQLException, RuntimeException)
 {
 	ADORecordset *pRecordset = m_pADOConnection->getColumns(catalog,schemaPattern,tableNamePattern,columnNamePattern);
 	ADOS::ThrowException(*m_pADOConnection,*this);
 
 	Reference< XResultSet > xRef;
-	
+
 	ODatabaseMetaDataResultSet* pResult = new ODatabaseMetaDataResultSet(pRecordset);
 	pResult->setColumnsMap();
 	xRef = pResult;
@@ -200,15 +203,15 @@ Reference< XResultSet > SAL_CALL ODatabaseMetaData::getColumns(
 	return xRef;
 }
 // -------------------------------------------------------------------------
-Reference< XResultSet > SAL_CALL ODatabaseMetaData::getTables( 
-	const Any& catalog, const ::rtl::OUString& schemaPattern, 
+Reference< XResultSet > SAL_CALL ODatabaseMetaData::getTables(
+	const Any& catalog, const ::rtl::OUString& schemaPattern,
 	const ::rtl::OUString& tableNamePattern, const Sequence< ::rtl::OUString >& types ) throw(SQLException, RuntimeException)
-{			
+{
 	ADORecordset *pRecordset = m_pADOConnection->getTables(catalog,schemaPattern,tableNamePattern,types);
 	ADOS::ThrowException(*m_pADOConnection,*this);
 
 	Reference< XResultSet > xRef;
-	
+
 	ODatabaseMetaDataResultSet* pResult = new ODatabaseMetaDataResultSet(pRecordset);
 	pResult->setTablesMap();
 	xRef = pResult;
@@ -216,15 +219,15 @@ Reference< XResultSet > SAL_CALL ODatabaseMetaData::getTables(
 	return xRef;
 }
 // -------------------------------------------------------------------------
-Reference< XResultSet > SAL_CALL ODatabaseMetaData::getProcedureColumns( 
-	const Any& catalog, const ::rtl::OUString& schemaPattern, 
+Reference< XResultSet > SAL_CALL ODatabaseMetaData::getProcedureColumns(
+	const Any& catalog, const ::rtl::OUString& schemaPattern,
 	const ::rtl::OUString& procedureNamePattern, const ::rtl::OUString& columnNamePattern ) throw(SQLException, RuntimeException)
 {
 	ADORecordset *pRecordset = m_pADOConnection->getProcedureColumns(catalog,schemaPattern,procedureNamePattern,columnNamePattern);
 	ADOS::ThrowException(*m_pADOConnection,*this);
 
 	Reference< XResultSet > xRef;
-	
+
 	ODatabaseMetaDataResultSet* pResult = new ODatabaseMetaDataResultSet(pRecordset);
 	pResult->setProcedureColumnsMap();
 	xRef = pResult;
@@ -232,8 +235,8 @@ Reference< XResultSet > SAL_CALL ODatabaseMetaData::getProcedureColumns(
 	return xRef;
 }
 // -------------------------------------------------------------------------
-Reference< XResultSet > SAL_CALL ODatabaseMetaData::getProcedures( 
-	const Any& catalog, const ::rtl::OUString& schemaPattern, 
+Reference< XResultSet > SAL_CALL ODatabaseMetaData::getProcedures(
+	const Any& catalog, const ::rtl::OUString& schemaPattern,
 	const ::rtl::OUString& procedureNamePattern ) throw(SQLException, RuntimeException)
 {
 	// Create elements used in the array
@@ -241,16 +244,16 @@ Reference< XResultSet > SAL_CALL ODatabaseMetaData::getProcedures(
 	ADOS::ThrowException(*m_pADOConnection,*this);
 
 	Reference< XResultSet > xRef;
-	
+
 	ODatabaseMetaDataResultSet* pResult = new ODatabaseMetaDataResultSet(pRecordset);
 	pResult->setProceduresMap();
 	xRef = pResult;
-	
+
 	return xRef;
 }
 // -------------------------------------------------------------------------
-Reference< XResultSet > SAL_CALL ODatabaseMetaData::getVersionColumns( 
-	const Any& catalog, const ::rtl::OUString& schema, const ::rtl::OUString& table ) throw(SQLException, RuntimeException)
+Reference< XResultSet > SAL_CALL ODatabaseMetaData::getVersionColumns(
+	const Any& /*catalog*/, const ::rtl::OUString& /*schema*/, const ::rtl::OUString& /*table*/ ) throw(SQLException, RuntimeException)
 {
     Reference< XResultSet > xRef;
     ::connectivity::ODatabaseMetaDataResultSet* pResult = new ::connectivity::ODatabaseMetaDataResultSet();
@@ -320,7 +323,7 @@ sal_Int32 SAL_CALL ODatabaseMetaData::getMaxTablesInSelect(  ) throw(SQLExceptio
 	return getInt32Property(::rtl::OUString::createFromAscii("Maximum Tables in SELECT"));
 }
 // -------------------------------------------------------------------------
-Reference< XResultSet > SAL_CALL ODatabaseMetaData::getExportedKeys( 
+Reference< XResultSet > SAL_CALL ODatabaseMetaData::getExportedKeys(
 	const Any& catalog, const ::rtl::OUString& schema, const ::rtl::OUString& table ) throw(SQLException, RuntimeException)
 {
 	ADORecordset *pRecordset = m_pADOConnection->getExportedKeys(catalog,schema,table);
@@ -330,33 +333,33 @@ Reference< XResultSet > SAL_CALL ODatabaseMetaData::getExportedKeys(
 	ODatabaseMetaDataResultSet* pResult = new ODatabaseMetaDataResultSet(pRecordset);
 	pResult->setCrossReferenceMap();
 	xRef = pResult;
-	
+
 	return xRef;
 }
 // -------------------------------------------------------------------------
-Reference< XResultSet > SAL_CALL ODatabaseMetaData::getImportedKeys( 
+Reference< XResultSet > SAL_CALL ODatabaseMetaData::getImportedKeys(
 	const Any& catalog, const ::rtl::OUString& schema, const ::rtl::OUString& table ) throw(SQLException, RuntimeException)
 {
 	ADORecordset *pRecordset = m_pADOConnection->getImportedKeys(catalog,schema,table);
 	ADOS::ThrowException(*m_pADOConnection,*this);
 
 	Reference< XResultSet > xRef;
-	
+
 	ODatabaseMetaDataResultSet* pResult = new ODatabaseMetaDataResultSet(pRecordset);
 	pResult->setCrossReferenceMap();
 	xRef = pResult;
-	
+
 	return xRef;
 }
 // -------------------------------------------------------------------------
-Reference< XResultSet > SAL_CALL ODatabaseMetaData::getPrimaryKeys( 
+Reference< XResultSet > SAL_CALL ODatabaseMetaData::getPrimaryKeys(
 	const Any& catalog, const ::rtl::OUString& schema, const ::rtl::OUString& table ) throw(SQLException, RuntimeException)
 {
 	ADORecordset *pRecordset = m_pADOConnection->getPrimaryKeys(catalog,schema,table);
 	ADOS::ThrowException(*m_pADOConnection,*this);
 
 	Reference< XResultSet > xRef;
-	
+
 	ODatabaseMetaDataResultSet* pResult = new ODatabaseMetaDataResultSet(pRecordset);
 	pResult->setPrimaryKeysMap();
 	xRef = pResult;
@@ -364,25 +367,25 @@ Reference< XResultSet > SAL_CALL ODatabaseMetaData::getPrimaryKeys(
 	return xRef;
 }
 // -------------------------------------------------------------------------
-Reference< XResultSet > SAL_CALL ODatabaseMetaData::getIndexInfo( 
-	const Any& catalog, const ::rtl::OUString& schema, const ::rtl::OUString& table, 
+Reference< XResultSet > SAL_CALL ODatabaseMetaData::getIndexInfo(
+	const Any& catalog, const ::rtl::OUString& schema, const ::rtl::OUString& table,
 	sal_Bool unique, sal_Bool approximate ) throw(SQLException, RuntimeException)
 {
 	ADORecordset *pRecordset = m_pADOConnection->getIndexInfo(catalog,schema,table,unique,approximate);
 	ADOS::ThrowException(*m_pADOConnection,*this);
 
 	Reference< XResultSet > xRef;
-	
+
 	ODatabaseMetaDataResultSet* pResult = new ODatabaseMetaDataResultSet(pRecordset);
 	pResult->setIndexInfoMap();
 	xRef = pResult;
-	
+
 	return xRef;
 }
 // -------------------------------------------------------------------------
-Reference< XResultSet > SAL_CALL ODatabaseMetaData::getBestRowIdentifier( 
-	const Any& catalog, const ::rtl::OUString& schema, const ::rtl::OUString& table, sal_Int32 scope, 
-	sal_Bool nullable ) throw(SQLException, RuntimeException)
+Reference< XResultSet > SAL_CALL ODatabaseMetaData::getBestRowIdentifier(
+	const Any& /*catalog*/, const ::rtl::OUString& /*schema*/, const ::rtl::OUString& /*table*/, sal_Int32 /*scope*/,
+	sal_Bool /*nullable*/ ) throw(SQLException, RuntimeException)
 {
 	Reference< XResultSet > xRef;
 
@@ -392,14 +395,14 @@ Reference< XResultSet > SAL_CALL ODatabaseMetaData::getBestRowIdentifier(
 	return xRef;
 }
 // -------------------------------------------------------------------------
-Reference< XResultSet > SAL_CALL ODatabaseMetaData::getTablePrivileges( 
+Reference< XResultSet > SAL_CALL ODatabaseMetaData::getTablePrivileges(
 	const Any& catalog, const ::rtl::OUString& schemaPattern, const ::rtl::OUString& tableNamePattern ) throw(SQLException, RuntimeException)
 {
 	Reference< XResultSet > xRef;
 	if(!ADOS::isJetEngine(m_pConnection->getEngineType()))
 	{	// the jet provider doesn't support this method
 		// Create elements used in the array
-		
+
 		ADORecordset *pRecordset = m_pADOConnection->getTablePrivileges(catalog,schemaPattern,tableNamePattern);
 		ADOS::ThrowException(*m_pADOConnection,*this);
 
@@ -446,20 +449,20 @@ Reference< XResultSet > SAL_CALL ODatabaseMetaData::getTablePrivileges(
 	return xRef;
 }
 // -------------------------------------------------------------------------
-Reference< XResultSet > SAL_CALL ODatabaseMetaData::getCrossReference( 
-	const Any& primaryCatalog, const ::rtl::OUString& primarySchema, 
-	const ::rtl::OUString& primaryTable, const Any& foreignCatalog, 
+Reference< XResultSet > SAL_CALL ODatabaseMetaData::getCrossReference(
+	const Any& primaryCatalog, const ::rtl::OUString& primarySchema,
+	const ::rtl::OUString& primaryTable, const Any& foreignCatalog,
 	const ::rtl::OUString& foreignSchema, const ::rtl::OUString& foreignTable ) throw(SQLException, RuntimeException)
 {
-	ADORecordset *pRecordset = m_pADOConnection->getCrossReference(primaryCatalog,primarySchema,primaryTable,foreignCatalog,foreignSchema,foreignTable);	
+	ADORecordset *pRecordset = m_pADOConnection->getCrossReference(primaryCatalog,primarySchema,primaryTable,foreignCatalog,foreignSchema,foreignTable);
 	ADOS::ThrowException(*m_pADOConnection,*this);
 
 	Reference< XResultSet > xRef;
-	
+
 	ODatabaseMetaDataResultSet* pResult = new ODatabaseMetaDataResultSet(pRecordset);
 	pResult->setCrossReferenceMap();
 	xRef = pResult;
-	
+
 	return xRef;
 }
 // -------------------------------------------------------------------------
@@ -758,7 +761,7 @@ sal_Bool SAL_CALL ODatabaseMetaData::supportsTableCorrelationNames(  ) throw(SQL
 	return isCapable(DBLITERAL_CORRELATION_NAME);
 }
 // -------------------------------------------------------------------------
-sal_Bool SAL_CALL ODatabaseMetaData::supportsConvert( sal_Int32 fromType, sal_Int32 toType ) throw(SQLException, RuntimeException)
+sal_Bool SAL_CALL ODatabaseMetaData::supportsConvert( sal_Int32 /*fromType*/, sal_Int32 /*toType*/ ) throw(SQLException, RuntimeException)
 {
 	return getBoolProperty(::rtl::OUString::createFromAscii("Rowset Conversions on Command"));
 }
@@ -1077,12 +1080,12 @@ sal_Int32 SAL_CALL ODatabaseMetaData::getMaxUserNameLength(  ) throw(SQLExceptio
 	return getMaxSize(DBLITERAL_USER_NAME);
 }
 // -------------------------------------------------------------------------
-sal_Bool SAL_CALL ODatabaseMetaData::supportsResultSetType( sal_Int32 setType ) throw(SQLException, RuntimeException)
+sal_Bool SAL_CALL ODatabaseMetaData::supportsResultSetType( sal_Int32 /*setType*/ ) throw(SQLException, RuntimeException)
 {
 	return sal_True;
 }
 // -------------------------------------------------------------------------
-sal_Bool SAL_CALL ODatabaseMetaData::supportsResultSetConcurrency( sal_Int32 setType, sal_Int32 concurrency ) throw(SQLException, RuntimeException)
+sal_Bool SAL_CALL ODatabaseMetaData::supportsResultSetConcurrency( sal_Int32 /*setType*/, sal_Int32 /*concurrency*/ ) throw(SQLException, RuntimeException)
 {
 	return sal_True;
 }
@@ -1137,13 +1140,10 @@ sal_Bool SAL_CALL ODatabaseMetaData::supportsBatchUpdates(  ) throw(SQLException
 	return sal_True;
 }
 // -------------------------------------------------------------------------
-Reference< XResultSet > SAL_CALL ODatabaseMetaData::getUDTs( const Any& catalog, const ::rtl::OUString& schemaPattern, const ::rtl::OUString& typeNamePattern, const Sequence< sal_Int32 >& types ) throw(SQLException, RuntimeException)
+Reference< XResultSet > SAL_CALL ODatabaseMetaData::getUDTs( const Any& /*catalog*/, const ::rtl::OUString& /*schemaPattern*/, const ::rtl::OUString& /*typeNamePattern*/, const Sequence< sal_Int32 >& /*types*/ ) throw(SQLException, RuntimeException)
 {
-	Reference< XResultSet > xRef;
-	
-	ODatabaseMetaDataResultSet* pResult = new ODatabaseMetaDataResultSet(NULL);
-	xRef = pResult;
-	return xRef;
+    ::dbtools::throwFeatureNotImplementedException( "XDatabaseMetaData::getUDTs", *this );
+    return Reference< XResultSet >();
 }
 // -------------------------------------------------------------------------
 Reference< XConnection > SAL_CALL ODatabaseMetaData::getConnection(  ) throw(SQLException, RuntimeException)
