@@ -4,9 +4,9 @@
  *
  *  $RCSfile: soreport.cpp,v $
  *
- *  $Revision: 1.18 $
+ *  $Revision: 1.19.6.1 $
  *
- *  last change: $Author: hr $ $Date: 2005/09/28 13:01:20 $
+ *  last change: $Author: hr $ $Date: 2006/08/29 15:11:18 $
  *
  *  The Contents of this file are made available subject to
  *  the terms of GNU Lesser General Public License Version 2.1.
@@ -35,6 +35,10 @@
 
 #define UNICODE
 #define WIN32_LEAN_AND_MEAN
+#if defined _MSC_VER
+#pragma warning(push, 1)
+#pragma warning(disable:4917)
+#endif
 #include <windows.h>
 #include <windowsx.h>
 
@@ -52,6 +56,9 @@
 #define _RICHEDIT_VER	0x0200
 #include <richedit.h>
 
+#if defined _MSC_VER
+#pragma warning(pop)
+#endif 
 
 #if _RICHEDIT_VER >= 0x0200
 #define RICHEDIT	TEXT("riched20.dll")
@@ -125,6 +132,26 @@ bool	g_bLoadReport = false;
 // tmpfile from msvcrt creates the temporary file in the root of the current
 // volume and can fail.
 
+static FILE *_xfopen( const _TCHAR *file, const _TCHAR *mode )
+{
+#ifdef UNICODE
+	if ( (LONG)GetVersion() < 0 )
+	{
+		char	afile[MAX_PATH];
+		char	amode[16];
+
+		WideCharToMultiByte( CP_ACP, 0, file, -1, afile, MAX_PATH, NULL, NULL );
+		WideCharToMultiByte( CP_ACP, 0, mode, -1, amode, 16, NULL, NULL );
+
+
+		return fopen( afile, amode );
+	}
+	else
+#endif
+		return _tfopen( file, mode );
+}
+
+
 static FILE *_tmpfile(void)
 {
 	FILE *fp = NULL;
@@ -196,7 +223,7 @@ static FILE *_open_reportfile( LPCTSTR lpExt, LPCTSTR lpMode )
 		_tcscat( szAppDataPath, _T("\\crashdat") );
 		_tcscat( szAppDataPath, lpExt );
 
-		fp = _tfopen( szAppDataPath, lpMode );
+		fp = _xfopen( szAppDataPath, lpMode );
 	}
 
 	return fp;
@@ -413,7 +440,7 @@ void CrashReportParams::ReadFromEnvironment()
 
 	if ( dwResult && dwResult < elementsof(szBuffer) )
 	{
-		FILE *fp = _tfopen( szBuffer, _T("rb") );
+		FILE *fp = _xfopen( szBuffer, _T("rb") );
 
 		if ( fp )
 		{
@@ -584,7 +611,6 @@ static size_t fcopy( FILE *fpin, FILE *fpout )
 
 static string GetModuleDirectory( HMODULE hModule )
 {
-	TCHAR	szBuffer[256] = TEXT("");
 	TCHAR	szModuleName[MAX_PATH] = TEXT("");
 	TCHAR	szDrive[_MAX_DRIVE];
 	TCHAR	szDir[_MAX_DIR];
@@ -940,7 +966,7 @@ BOOL CALLBACK PreviewDialogProc(
 						TCHAR	output[2];
 
 						if ( (int)buf[i] >= 0x20 && (int)buf[i] <= 0x7F )
-							output[0] = (int)buf[i];
+							output[0] = (TCHAR)buf[i];
 						else
 							output[0] = '.';
 						output[1] = 0;
@@ -1025,7 +1051,7 @@ BOOL CALLBACK OptionsDialogProc(
 		{
 			TCHAR	szBuffer[1024] = TEXT("");
 			HINSTANCE	hInstance = (HINSTANCE)GetWindowLong( hwndDlg, GWL_HINSTANCE );
-			HWND	hwndParent = (HWND)GetWindowLong( hwndDlg, GWL_HWNDPARENT );
+			//HWND	hwndParent = (HWND)GetWindowLong( hwndDlg, GWL_HWNDPARENT );
 
 			pParams = (CrashReportParams *)lParam;
 
@@ -1144,7 +1170,7 @@ BOOL CALLBACK ReportDialogProc(
 	HWND hwndDlg, 
 	UINT uMsg, 
 	WPARAM wParam, 
-	LPARAM lParam 
+	LPARAM 
 	)
 {
 	switch ( uMsg )
@@ -1556,7 +1582,7 @@ static sal_uInt32 calc_md5_checksum(  const char *filename, sal_uInt8 *pChecksum
 			sal_uInt8 *pBuffer = new sal_uInt8[nFileSize];
 			size_t nBytesRead = fread( pBuffer, 1, nFileSize, fp );
 			
-			if ( nBytesRead == nFileSize )
+			if ( sal::static_int_cast<long>(nBytesRead) == nFileSize )
 			{
 				if ( 0 == stricmp( GetFileName(filename).c_str(), "soffice.bin" ) )
 					repatch_soffice_exe( pBuffer, nBytesRead );
@@ -2174,7 +2200,7 @@ static string get_script_string( const char *pFileName, const char *pKeyName )
 				string	keyname = line.substr( 0, iEqualSign );
 				keyname = trim_string( keyname );
 				
-				string	value = line.substr( iEqualSign + 1, -1 );
+				string	value = line.substr( sal::static_int_cast<string::size_type>(iEqualSign + 1) );
 				value = trim_string( value );
 
 				if ( value.length() && '\"' == value[0] )
@@ -2510,7 +2536,7 @@ BOOL CALLBACK SendingStatusDialogProc(
 		{
 			TCHAR	szBuffer[1024] = TEXT("");
 			HINSTANCE	hInstance = (HINSTANCE)GetWindowLong( hwndDlg, GWL_HINSTANCE );
-			HWND	hwndParent = (HWND)GetWindowLong( hwndDlg, GWL_HWNDPARENT );
+			//HWND	hwndParent = (HWND)GetWindowLong( hwndDlg, GWL_HWNDPARENT );
 
 			pRequest = (RequestParams *)lParam;
 
@@ -2716,7 +2742,7 @@ bool SendCrashReport( HWND hwndParent, const CrashReportParams &rParams )
 
 //***************************************************************************
 
-int WINAPI _tWinMain( HINSTANCE hInstance, HINSTANCE, LPTSTR lpCmdLine, int )
+int WINAPI _tWinMain( HINSTANCE hInstance, HINSTANCE, LPTSTR /*lpCmdLine*/, int )
 {
 	int exitcode = -1;
 	int argc = __argc;
