@@ -308,10 +308,10 @@ hentry * Hunspell::spellsharps(char * base, char * pos, int n, int repnum, char
         hentry * h;
         *pos = '';
         *(pos + 1) = '';
-        if (h = spellsharps(base, pos + 2, n + 1, repnum + 1, tmp)) return h;
+        if ((h = spellsharps(base, pos + 2, n + 1, repnum + 1, tmp))) return h;
         *pos = 's';
         *(pos + 1) = 's';
-        if (h = spellsharps(base, pos + 2, n + 1, repnum, tmp)) return h;
+        if ((h = spellsharps(base, pos + 2, n + 1, repnum, tmp))) return h;
     } else if (repnum > 0) {
         if (utf8) return check(base);
         return check(sharps_u8_l1(tmp, base));
@@ -347,7 +347,7 @@ int Hunspell::spell(const char * word)
   char wspace[MAXWORDUTF8LEN + 4];
   w_char unicw[MAXWORDLEN + 1];
   int nc = strlen(word);
-  int wl2;
+  int wl2 = 0;
   if (utf8) {
     if (nc >= MAXWORDUTF8LEN) return 0;
   } else {
@@ -457,12 +457,12 @@ int Hunspell::spell(const char * word)
   if (wordbreak) {
     char * s;
     char r;
-    for (int i = 0; i < pAMgr->get_numbreak(); i++) {
-      if (s=(char *) strstr(cw, wordbreak[i])) {
+    for (int j = 0; j < pAMgr->get_numbreak(); j++) {
+      if ((s=(char *) strstr(cw, wordbreak[j]))) {
         r = *s;
         *s = '\0';
         // examine 2 sides of the break point
-        if (spell(cw) && spell(s + strlen(wordbreak[i]))) {
+        if (spell(cw) && spell(s + strlen(wordbreak[j]))) {
             *s = r;
             return 1;
         }
@@ -663,8 +663,8 @@ int Hunspell::suggest(char*** slst, const char * word)
                         }
                         // aNew -> "a New" (instead of "a new")
                         for (int j = prevns; j < ns; j++) {
-                           char * space;
-                           if (space = strchr((*slst)[j],' ')) {
+                           char * space = strchr((*slst)[j],' ');
+                           if (space) {
                                 int slen = strlen(space + 1);
                                 // different case after space (need capitalisation)
                                 if ((slen < wl) && strcmp(cw + wl - slen, space + 1)) {
@@ -696,12 +696,12 @@ int Hunspell::suggest(char*** slst, const char * word)
                         if (pAMgr && pAMgr->get_checksharps()) {
                             char * pos;
                             if (utf8) {
-                                while (pos = strstr((*slst)[j], "ß")) {
+                                while ((pos = strstr((*slst)[j], "ß"))) {
                                     *pos = 'S';
                                     *(pos+1) = 'S';
                                 }
                             } else {
-                                while (pos = strchr((*slst)[j], '')) {
+                                while ((pos = strchr((*slst)[j], ''))) {
                                     (*slst)[j] = (char *) realloc((*slst)[j], strlen((*slst)[j]) + 2);
                                     mystrrep((*slst)[j], "", "SS");
                                 }
@@ -790,13 +790,13 @@ int Hunspell::suggest(char*** slst, const char * word)
             strcpy(s, (*slst)[j]);
             len = strlen(s);
           }
-          int wl = mkallsmall2(s, w, len);
+          /*int wl = */mkallsmall2(s, w, len);
           free((*slst)[j]);          
           if (spell(s)) {
             (*slst)[l] = mystrdup(s);
             l++;
           } else {
-            int wl = mkinitcap2(s, w, len);
+            /*int wl = */mkinitcap2(s, w, len);
             if (spell(s)) {
               (*slst)[l] = mystrdup(s);
               l++;
