@@ -4,9 +4,9 @@
  *
  *  $RCSfile: documen2.cxx,v $
  *
- *  $Revision: 1.56.10.1 $
+ *  $Revision: 1.58 $
  *
- *  last change: $Author: rt $ $Date: 2006/06/15 13:53:17 $
+ *  last change: $Author: kz $ $Date: 2006/07/21 10:51:42 $
  *
  *  The Contents of this file are made available subject to
  *  the terms of GNU Lesser General Public License Version 2.1.
@@ -33,6 +33,9 @@
  *
  ************************************************************************/
 
+// MARKER(update_precomp.py): autogen include statement, do not remove
+#include "precompiled_sc.hxx"
+
 #define _BIGINT_HXX
 #define _SFXMULTISEL_HXX
 //#define _STACK_HXX
