@@ -4,9 +4,9 @@
  *
  *  $RCSfile: consdlg.cxx,v $
  *
- *  $Revision: 1.9 $
+ *  $Revision: 1.10 $
  *
- *  last change: $Author: rt $ $Date: 2005/09/08 20:31:00 $
+ *  last change: $Author: kz $ $Date: 2006/07/21 13:17:49 $
  *
  *  The Contents of this file are made available subject to
  *  the terms of GNU Lesser General Public License Version 2.1.
@@ -33,13 +33,12 @@
  *
  ************************************************************************/
 
+// MARKER(update_precomp.py): autogen include statement, do not remove
+#include "precompiled_sc.hxx"
+
 // System - Includes ---------------------------------------------------------
 
-#ifdef PCH
-#include "ui_pch.hxx"
-#endif
 
-#pragma hdrstop
 
 #include <sfx2/dispatch.hxx>
 
