@@ -4,9 +4,9 @@
  *
  *  $RCSfile: undoblk.cxx,v $
  *
- *  $Revision: 1.21 $
+ *  $Revision: 1.23 $
  *
- *  last change: $Author: rt $ $Date: 2006/01/13 17:06:43 $
+ *  last change: $Author: kz $ $Date: 2006/07/21 14:26:10 $
  *
  *  The Contents of this file are made available subject to
  *  the terms of GNU Lesser General Public License Version 2.1.
@@ -33,11 +33,10 @@
  *
  ************************************************************************/
 
-#ifdef PCH
-#include "ui_pch.hxx"
-#endif
+// MARKER(update_precomp.py): autogen include statement, do not remove
+#include "precompiled_sc.hxx"
+
 
-#pragma hdrstop
 
 //------------------------------------------------------------------
 
@@ -1026,10 +1025,14 @@ void __EXPORT ScUndoPaste::Repeat(SfxRepeatTarget& rTarget)
 		ScTabViewShell* pViewSh = ((ScTabViewTarget&)rTarget).GetViewShell();
 		ScTransferObj* pOwnClip = ScTransferObj::GetOwnClipboard( pViewSh->GetActiveWin() );
 		if (pOwnClip)
+        {
+            // #129384# keep a reference in case the clipboard is changed during PasteFromClip
+            com::sun::star::uno::Reference<com::sun::star::datatransfer::XTransferable> aOwnClipRef( pOwnClip );
 			pViewSh->PasteFromClip( nFlags, pOwnClip->GetDocument(),
 									aPasteOptions.nFunction, aPasteOptions.bSkipEmpty, aPasteOptions.bTranspose,
 									aPasteOptions.bAsLink, aPasteOptions.eMoveMode, IDF_NONE,
 									TRUE );		// allow warning dialog
+        }
 	}
 }
 
