@@ -4,9 +4,9 @@
  *
  *  $RCSfile: pastedlg.cxx,v $
  *
- *  $Revision: 1.20 $
+ *  $Revision: 1.21 $
  *
- *  last change: $Author: rt $ $Date: 2005/09/07 21:45:02 $
+ *  last change: $Author: hr $ $Date: 2006/06/19 12:21:19 $
  *
  *  The Contents of this file are made available subject to
  *  the terms of GNU Lesser General Public License Version 2.1.
@@ -57,7 +57,6 @@
 #include <svtools/transfer.hxx>
 #endif
 #include <sot/stg.hxx>
-#pragma hdrstop
 
 
 #include "helpid.hrc"
@@ -130,6 +129,7 @@ void SvPasteDlg::SelectObject()
 
 IMPL_LINK( SvPasteDlg, SelectHdl, ListBox *, pListBox )
 {
+	(void)pListBox;
 	if ( !aOKButton1.IsEnabled() )
 		aOKButton1.Enable();
 	return 0;
@@ -137,6 +137,7 @@ IMPL_LINK( SvPasteDlg, SelectHdl, ListBox *, pListBox )
 
 IMPL_LINK_INLINE_START( SvPasteDlg, DoubleClickHdl, ListBox *, pListBox )
 {
+	(void)pListBox;
 	EndDialog( RET_OK );
 	return 0;
 }
