@@ -4,9 +4,9 @@
  *
  *  $RCSfile: javacompskeleton.cxx,v $
  *
- *  $Revision: 1.5 $
+ *  $Revision: 1.8 $
  *
- *  last change: $Author: vg $ $Date: 2006/03/15 09:18:35 $
+ *  last change: $Author: ihi $ $Date: 2006/08/01 16:24:24 $
  *
  *  The Contents of this file are made available subject to
  *  the terms of GNU Lesser General Public License Version 2.1.
@@ -47,14 +47,13 @@ namespace skeletonmaker { namespace java {
 
 void generatePackage(std::ostream & o, const OString & implname)
 {
-    short count=0;
     sal_Int32 index = implname.lastIndexOf('.');
     if (index != -1)
         o << "package " << implname.copy(0, index) << ";\n\n";
 }
 
 void generateImports(std::ostream & o,
-         const std::hash_set< OString, OStringHash >& interfaces,
+         const std::hash_set< OString, OStringHash >& /*interfaces*/,
          const OString & propertyhelper,
          bool serviceobject, bool supportxcomponent)
 {
@@ -270,7 +269,7 @@ bool checkAttribute(OStringBuffer& attributeValue, sal_uInt16 attribute)
 }
 
 void registerProperties(std::ostream& o,
-                        TypeManager const & manager,
+                        TypeManager const & /*manager*/,
                         const AttributeInfo& properties,
                         const OString& indentation)
 {
@@ -298,8 +297,7 @@ void registerProperties(std::ostream& o,
     }    
 }
 
-void generateXAddInBodies(std::ostream& o, ProgramOptions const & options)
-{
+void generateXLocalizableBodies(std::ostream& o) {
     // com.sun.star.lang.XLocalizable:
     // setLocale
     o << "    // com.sun.star.lang.XLocalizable:\n"
@@ -309,7 +307,10 @@ void generateXAddInBodies(std::ostream& o, ProgramOptions const & options)
     // getLocale
     o << "    public com.sun.star.lang.Locale getLocale()\n    {\n"
         "        return m_locale;\n    }\n\n";
+}
 
+void generateXAddInBodies(std::ostream& o, ProgramOptions const & options)
+{
     // com.sun.star.sheet.XAddIn:
     // getProgrammaticFuntionName
     o << "    // com.sun.star.sheet.XAddIn:\n"
@@ -454,6 +455,7 @@ void generateMethodBodies(std::ostream& o,
         iter++;
         if (type.equals("com.sun.star.lang.XServiceInfo")) {
             generateXServiceInfoBodies(o);
+            generated.add(type);
         } else {
             if (options.componenttype == 2) {
                 if (type.equals("com.sun.star.lang.XServiceName")) {
@@ -465,6 +467,16 @@ void generateMethodBodies(std::ostream& o,
                 } else if (type.equals("com.sun.star.sheet.XAddIn")) {
                     generateXAddInBodies(o, options);
                     generated.add(type);
+
+                    // special handling of XLocalizable -> parent of XAddIn
+                    if (!generated.contains("com.sun.star.lang.XLocalizable")) {
+                        generateXLocalizableBodies(o);
+                        generated.add("com.sun.star.lang.XLocalizable");
+                    }
+                    continue;
+                } else if (type.equals("com.sun.star.lang.XLocalizable")) {
+                    generateXLocalizableBodies(o);
+                    generated.add(type);
                     continue;
                 } else if (type.equals("com.sun.star.sheet.XCompatibilityNames")) {
                     generateXCompatibilityNamesBodies(o);
@@ -493,9 +505,25 @@ void generateAddinConstructorAndHelper(std::ostream& o,
          const std::hash_set< OString, OStringHash >& services,
          const std::hash_set< OString, OStringHash >& interfaces)
 {
-    // get the one and only add-in service for later use
-    OString sAddinService = (*services.begin()).replace('/', '.');
+    o << "    private com.sun.star.lang.Locale m_locale = "
+        "new com.sun.star.lang.Locale();\n";
 
+    if (!options.backwardcompatible) {
+        // Constructor
+        o << "\n    public " << classname << "( XComponentContext context )\n"
+            "    {\n        m_xContext = context;\n    }\n\n";
+        return;
+    }
+        
+
+    // get the one and only add-in service for later use
+    std::hash_set< OString, OStringHash >::const_iterator iter = services.begin();
+    OString sAddinService = (*iter).replace('/', '.');
+    if (sAddinService.equals("com.sun.star.sheet.AddIn")) {
+        sAddinService = (*(++iter)).replace('/', '.');
+    } 
+
+        
     // add-in specific fields
     o << "\n    private static final String sADDIN_SERVICENAME = \""
       << sAddinService << "\";\n\n";
@@ -507,9 +535,7 @@ void generateAddinConstructorAndHelper(std::ostream& o,
         "    private static final String sCATEGORYDISPLAYNAME = "
         "\"CategoryDisplayName\";\n\n";
 
-    o << "    private com.sun.star.lang.Locale m_locale = "
-        "new com.sun.star.lang.Locale();\n"
-        "    private com.sun.star.container.XHierarchicalNameAccess  "
+    o << "    private com.sun.star.container.XHierarchicalNameAccess  "
         "m_xHAccess = null;\n"
         "    private com.sun.star.container.XHierarchicalNameAccess  "
         "m_xCompAccess = null;\n";
@@ -546,7 +572,7 @@ void generateAddinConstructorAndHelper(std::ostream& o,
         "\"com.sun.star.configuration.ConfigurationAccess\";\n\n";
 
     o << "        StringBuffer sPath = new StringBuffer(\n"
-        "             \"/org.openoffice.Office.Sheet.CalcAddIns/AddInInfo/\");\n"
+        "             \"/org.openoffice.Office.CalcAddIns/AddInInfo/\");\n"
         "        sPath.append(sADDIN_SERVICENAME);\n"
         "        sPath.append(\"/AddInFunctions\");\n\n";
 
@@ -558,8 +584,9 @@ void generateAddinConstructorAndHelper(std::ostream& o,
         "             com.sun.star.uno.Type.STRING, sPath.toString());\n\n";
     
     o << "        Object aArguments[] = new Object[1];\n"
-        "        aArguments[0] = new com.sun.star.uno.Any(\n"
-        "            com.sun.star.beans.PropertyValue.class, aArgument);\n\n";
+        "        aArguments[0] = new com.sun.star.uno.Any("
+        " new com.sun.star.uno.Type(\n"
+        "            com.sun.star.beans.PropertyValue.class), aArgument);\n\n";
 
     o << "        // create the default view using default UI locale\n"
         "         Object xIface = \n"
@@ -574,13 +601,15 @@ void generateAddinConstructorAndHelper(std::ostream& o,
     o << "        // extends arguments to create a view for all locales to get "
         "simple\n        // access to the compatibilityname property\n"
         "        aArguments = new Object[2];\n"
-        "        aArguments[0] = new com.sun.star.uno.Any(\n"
-        "            com.sun.star.beans.PropertyValue.class, aArgument);\n"
+        "        aArguments[0] = new com.sun.star.uno.Any( "
+        "new com.sun.star.uno.Type(\n"
+        "            com.sun.star.beans.PropertyValue.class), aArgument);\n"
         "        aArgument.Name = \"locale\";\n"
         "        aArgument.Value = new com.sun.star.uno.Any(\n"
         "            com.sun.star.uno.Type.STRING, \"*\");\n"
-        "        aArguments[1] = new com.sun.star.uno.Any(\n"
-        "            com.sun.star.beans.PropertyValue.class, aArgument);\n\n";
+        "        aArguments[1] = new com.sun.star.uno.Any( "
+        " new com.sun.star.uno.Type(\n"
+        "            com.sun.star.beans.PropertyValue.class), aArgument);\n\n";
 
     o << "        // create view for all locales\n"
         "        xIface = xProvider.createInstanceWithArguments(sReadOnlyView, "
@@ -734,7 +763,7 @@ void generateClassDefinition(std::ostream& o,
 void generateSkeleton(ProgramOptions const & options,
                       TypeManager const & manager,
                       std::vector< OString > const & types,
-                      OString const & delegate)
+                      OString const & /*delegate*/)
 {
     std::hash_set< OString, OStringHash > interfaces;
     std::hash_set< OString, OStringHash > services;
@@ -756,19 +785,23 @@ void generateSkeleton(ProgramOptions const & options,
                 "for calc add-in components one and only one service type is "
                 "necessary! Please reference a valid type with the '-t' option.");
         }
- 
-        // add AddIn in suported service list, this service is currently necessary
-        // to identify all calc add-ins and to support the necessary add-in helper
-        // interfaces.
-        // This becomes obsolete in the future when this information is collected
-        // from the configuration
-        checkType(manager, "com.sun.star.sheet.AddIn",
-                  interfaces, services, properties);
-        // special case for XLocalization, it is exlicitly handled and will be
-        // necessary in the future as well
-//         if (interfaces.find("com.sun.star.lang.XLocalizable") ==
-//             interfaces.end())
-//             interfaces.insert("com.sun.star.lang.XLocalizable");    
+
+        // if backwardcompatible==true the AddIn service needs to be added to the
+        // suported service list, the necessary intefaces are mapped to the add-in
+        // configuration. Since OO.org 2.0.4 this is obsolete and the add-in is
+        // take form the configuration from Calc directly, this simplifies the
+        // add-in code
+        if (options.backwardcompatible) {
+            checkType(manager, "com.sun.star.sheet.AddIn",
+                      interfaces, services, properties);
+        } else {
+            // special case for the optional XLocalization interface. It should be
+            // implemented always. But it is parent of the XAddIn and we need it only
+            // if backwardcompatible is false.
+            if (interfaces.find("com.sun.star.lang.XLocalizable") == interfaces.end()) {
+                interfaces.insert("com.sun.star.lang.XLocalizable");
+            }
+        }
     }
 
     
